poets.timedate package
======================

Submodules
----------

poets.timedate.dateindex module
-------------------------------

.. automodule:: poets.timedate.dateindex
    :members:
    :undoc-members:
    :show-inheritance:

poets.timedate.dekad module
---------------------------

.. automodule:: poets.timedate.dekad
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: poets.timedate
    :members:
    :undoc-members:
    :show-inheritance:
